@@ -37,6 +37,8 @@ def cast_int(x):
     return int(x)
 
 
+construct_bytes = bytes
+
 dtype_from_string = {
     "float32": torch.float32,
     "float64": torch.float64,
@@ -49,7 +51,9 @@ dtype_from_string = {
 
 
 def scalar_to_tensor(scalar, shape, device_dtype):
-    return torch.full(shape, scalar, device=device_dtype.device, dtype=dtype_from_string[device_dtype.dtype])
+    "Makes a stride 0 repeat view into a 1 element tensor"
+    scalar_tensor = torch.tensor(scalar, device=device_dtype.device, dtype=dtype_from_string[device_dtype.dtype])
+    return torch.broadcast_to(scalar_tensor, tuple(shape))
 
 
 def tensor_scale(tensor):
