@@ -1,8 +1,9 @@
+use crate::{
+    circuit::EinsumAxes,
+    hashmaps::{AHashSet as HashSet, FxHashMap as HashMap},
+};
 use std::{
-    collections::{
-        hash_map::Entry::{self, Vacant},
-        HashMap, HashSet,
-    },
+    collections::hash_map::Entry::{self, Vacant},
     iter::zip,
     rc::Rc,
 };
@@ -10,7 +11,7 @@ use std::{
 use bit_iter::BitIter;
 use itertools::Itertools;
 
-use crate::{pyo3_prelude::*, util::BitMask128};
+use crate::{all_imports::RInts, pyo3_prelude::*, sv, util::BitMask128};
 
 use super::{
     computational_node::EinsumArgs, deep_map_unwrap, evaluate_fn, prelude::*, Add, Concat, Einsum,
@@ -288,8 +289,10 @@ pub fn einsum_nest_path(einsum: &Einsum, path: Vec<Vec<usize>>) -> Einsum {
                     .flat_map(|(_node, ints)| ints)
                     .copied()
                     .collect();
-                let mut outer_indices =
-                    Vec::from_iter(inner_indices_set.intersection(&outer_indices_set).copied());
+                let mut outer_indices: EinsumAxes = inner_indices_set
+                    .intersection(&outer_indices_set)
+                    .copied()
+                    .collect();
                 outer_indices.sort();
                 outer_indices
             }
@@ -329,8 +332,8 @@ pub fn deep_optimize_einsums(circ: CircuitRc) -> CircuitRc {
 /// corresponds to python function `construct_diag`
 pub fn expand_maybe_diag(
     node: &CircuitRc,
-    in_ints: &Vec<u8>,
-    out_ints: &Vec<u8>,
+    in_ints: &EinsumAxes,
+    out_ints: &EinsumAxes,
     int_sizes: &HashMap<u8, usize>,
 ) -> CircuitRc {
     if in_ints[..] == out_ints[..] {
@@ -339,24 +342,22 @@ pub fn expand_maybe_diag(
 
     // if no diag, just expand
     if is_unique(in_ints) && is_unique(out_ints) {
-        return Rearrange::try_new(
+        return Rearrange::nrc(
             node.clone(),
             RearrangeSpec::expand(in_ints, out_ints, int_sizes),
             None,
-        )
-        .unwrap()
-        .rc();
+        );
     }
 
     let mut cur_ints = in_ints.clone();
     let mut result = node.clone();
 
     // broadcast to have all diag dims
-    let out_int_appearances = unique_to_appearance(out_ints);
-    let ints_to_add_before_einsum: Vec<u8> = out_int_appearances
+    let out_int_appearances = unique_to_appearance(&out_ints.iter().collect());
+    let ints_to_add_before_einsum: EinsumAxes = out_int_appearances
         .iter()
         .filter(|(int, appearances)| appearances.len() > 1 && !in_ints.contains(int))
-        .map(|x| *x.0)
+        .map(|x| **x.0)
         .collect();
     if !ints_to_add_before_einsum.is_empty() {
         cur_ints = in_ints
@@ -364,7 +365,7 @@ pub fn expand_maybe_diag(
             .chain(ints_to_add_before_einsum.iter())
             .cloned()
             .collect();
-        result = Rearrange::try_new(
+        result = Rearrange::nrc(
             result,
             RearrangeSpec::expand(
                 &(0_u8..in_ints.len() as u8).collect(),
@@ -377,24 +378,20 @@ pub fn expand_maybe_diag(
             ),
             None,
         )
-        .unwrap()
-        .rc()
     }
 
     // make diag
-    let einsum_out_ints: Vec<u8> = out_ints
+    let einsum_out_ints: EinsumAxes = out_ints
         .iter()
         .filter(|i| cur_ints.contains(i))
         .cloned()
         .collect();
-    result = Einsum::try_new(vec![(result, cur_ints)], einsum_out_ints.clone(), None)
-        .unwrap()
-        .rc();
+    result = Einsum::nrc(vec![(result, cur_ints)], einsum_out_ints.clone(), None);
     cur_ints = einsum_out_ints;
 
     // add non-diag broadcast dims
     if cur_ints[..] != out_ints[..] {
-        result = Rearrange::try_new(
+        result = Rearrange::nrc(
             result,
             RearrangeSpec::expand(
                 &(0_u8..out_ints.len() as u8)
@@ -408,9 +405,7 @@ pub fn expand_maybe_diag(
                     .collect(),
             ),
             None,
-        )
-        .unwrap()
-        .rc();
+        );
     }
 
     result
@@ -428,21 +423,19 @@ pub fn make_broadcast(
         .enumerate()
         .map(|(i, x)| {
             if *x == 1 {
-                vec![]
+                sv![]
             } else {
-                vec![(i + rank_dif) as u8]
+                sv![(i + rank_dif) as u8]
             }
         })
         .collect();
-    let output_ints: Vec<Vec<u8>> = (0..(out_shape.len())).map(|i| vec![i as u8]).collect();
+    let output_ints: RInts = (0..(out_shape.len())).map(|i| sv![i as u8]).collect();
     let int_sizes = out_shape.clone();
-    Ok(Rearrange::try_new(
+    Ok(Rearrange::nrc(
         node.clone(),
         RearrangeSpec::new_canon(input_ints, output_ints, shape_to_op_shape(&int_sizes)),
         None,
-    )
-    .unwrap()
-    .rc())
+    ))
 }
 
 #[pyfunction]
@@ -453,7 +446,7 @@ pub fn einsum_elim_identity(einsum: &Einsum) -> Option<CircuitRc> {
     {
         Some(einsum.args[0].0.clone())
     } else if einsum.args.is_empty() {
-        Some(ScalarConstant::new(1.0, vec![], None).rc())
+        Some(ScalarConstant::new(1.0, sv![], None).rc())
     } else {
         None
     }
@@ -567,7 +560,9 @@ pub fn remove_axes(circuit: &CircuitRc, axes: &HashSet<usize>) -> Option<Circuit
         Circuit::ScalarConstant(scalar) => Some(
             ScalarConstant::new(
                 scalar.value,
-                filter_out_idx(&scalar.info().shape, axes),
+                filter_out_idx(&scalar.info().shape, axes)
+                    .into_iter()
+                    .collect(),
                 scalar.name_cloned(),
             )
             .rc(),
@@ -589,20 +584,16 @@ pub fn remove_axes(circuit: &CircuitRc, axes: &HashSet<usize>) -> Option<Circuit
                 .enumerate()
                 .all(|(i, l)| !axes.contains(&i) || *l == 1)
             {
-                Some(
-                    Rearrange::try_new(
-                        circuit.clone(),
-                        // wow this chained construction is long, should change at some point
-                        RearrangeSpec::ident(circuit.info().rank())
-                            .conform_to_input_shape(&circuit.info().shape, false)
-                            .unwrap()
-                            .canonicalize(true)
-                            .filter_out_axes_unsafe(axes),
-                        None,
-                    )
-                    .unwrap()
-                    .rc(),
-                )
+                Some(Rearrange::nrc(
+                    circuit.clone(),
+                    // wow this chained construction is long, should change at some point
+                    RearrangeSpec::ident(circuit.info().rank())
+                        .conform_to_input_shape(&circuit.info().shape, false)
+                        .unwrap()
+                        .canonicalize(true)
+                        .filter_out_axes_unsafe(axes),
+                    None,
+                ))
             } else {
                 None
             }
@@ -634,15 +625,11 @@ pub fn generalfunction_pull_removable_axes(node: &GeneralFunction) -> Option<Cir
         .iter()
         .map(|x| x + node.info().rank() - node.nodes[0].info().rank())
         .collect();
-    Some(
-        Rearrange::try_new(
-            new_generalfunction.rc(),
-            RearrangeSpec::unremove_axes(&removable_batchable_out, &node.info().shape),
-            None,
-        )
-        .unwrap()
-        .rc(),
-    )
+    Some(Rearrange::nrc(
+        new_generalfunction.rc(),
+        RearrangeSpec::unremove_axes(&removable_batchable_out, &node.info().shape),
+        None,
+    ))
 }
 
 #[pyfunction]
@@ -672,15 +659,11 @@ pub fn concat_pull_removable_axes(node: &Concat) -> Option<CircuitRc> {
         node.name_cloned(),
     )
     .unwrap();
-    Some(
-        Rearrange::try_new(
-            new_node.rc(),
-            RearrangeSpec::unremove_axes(&removable_non_axis, &node.info().shape),
-            None,
-        )
-        .unwrap()
-        .rc(),
-    )
+    Some(Rearrange::nrc(
+        new_node.rc(),
+        RearrangeSpec::unremove_axes(&removable_non_axis, &node.info().shape),
+        None,
+    ))
 }
 
 #[pyfunction]
@@ -695,7 +678,7 @@ pub fn einsum_pull_removable_axes(einsum: &Einsum) -> Option<CircuitRc> {
                 did_anything = true;
                 (
                     remove_axes(node, &removable_axes).unwrap(),
-                    filter_out_idx(ints, &removable_axes),
+                    filter_out_idx(ints, &removable_axes).into_iter().collect(),
                 )
             } else {
                 (node.clone(), ints.clone())
@@ -719,18 +702,16 @@ pub fn einsum_pull_removable_axes(einsum: &Einsum) -> Option<CircuitRc> {
         .map(|i| shape_map[i] as f64)
         .product();
     if scalar_mul != 1.0 {
-        new_args.push((ScalarConstant::new(scalar_mul, vec![], None).rc(), vec![]));
+        new_args.push((ScalarConstant::new(scalar_mul, sv![], None).rc(), sv![]));
     }
 
-    let new_out_ints: Vec<u8> = einsum
+    let new_out_ints: EinsumAxes = einsum
         .out_axes
         .iter()
         .filter(|i| ints_in_new_args.contains(i))
         .copied()
         .collect();
-    let new_einsum = Einsum::try_new(new_args, new_out_ints.clone(), einsum.name_cloned())
-        .unwrap()
-        .rc();
+    let new_einsum = Einsum::nrc(new_args, new_out_ints.clone(), einsum.name_cloned());
     if new_out_ints[..] == einsum.out_axes[..] {
         Some(new_einsum)
     } else {
@@ -789,9 +770,9 @@ pub fn add_pull_removable_axes(add: &Add, remove_non_common_axes: bool) -> Optio
     let post_rearrange_spec = RearrangeSpec::new_canon(
         (0..add.info().rank())
             .filter(|x| !intersection.contains(x))
-            .map(|x| vec![x as u8])
+            .map(|x| sv![x as u8])
             .collect(),
-        (0..add.info().rank()).map(|x| vec![x as u8]).collect(),
+        (0..add.info().rank()).map(|x| sv![x as u8]).collect(),
         shape_to_op_shape(&add.info().shape),
     );
     let new_operands = zip(&add.nodes, removable_axes)
@@ -810,16 +791,16 @@ pub fn add_pull_removable_axes(add: &Add, remove_non_common_axes: bool) -> Optio
                     .collect();
                 let raw_removed = remove_axes(node, &removable_here).unwrap();
 
-                let mut output_ints: Vec<Vec<u8>> = vec![];
+                let mut output_ints: RInts = sv![];
                 let mut count = 0;
                 let mut started = false;
                 for i in 0..node.info().rank() {
                     if removable_here.contains(&i) {
                         if started && !intersection.contains(&(i + rank_difference)) {
-                            output_ints.push(vec![]);
+                            output_ints.push(sv![]);
                         }
                     } else {
-                        output_ints.push(vec![count]);
+                        output_ints.push(sv![count]);
                         count += 1;
                         started = true;
                     }
@@ -827,23 +808,17 @@ pub fn add_pull_removable_axes(add: &Add, remove_non_common_axes: bool) -> Optio
 
                 let broadcast_rspec = RearrangeSpec::new_canon(
                     (0..raw_removed.info().rank())
-                        .map(|i| vec![i as u8])
+                        .map(|i| sv![i as u8])
                         .collect(),
                     output_ints,
                     shape_to_op_shape(&raw_removed.info().shape),
                 );
-                Rearrange::try_new(raw_removed, broadcast_rspec, None)
-                    .unwrap()
-                    .rc()
+                Rearrange::nrc(raw_removed, broadcast_rspec, None)
             }
         })
         .collect();
-    let add_circuit = Add::try_new(new_operands, add.name_cloned()).unwrap().rc();
-    Some(
-        Rearrange::try_new(add_circuit, post_rearrange_spec, None)
-            .unwrap()
-            .rc(),
-    )
+    let add_circuit = Add::nrc(new_operands, add.name_cloned());
+    Some(Rearrange::nrc(add_circuit, post_rearrange_spec, None))
 }
 
 #[pyfunction]
@@ -884,9 +859,7 @@ pub fn distribute(einsum: &Einsum, operand_idx: usize, do_broadcasts: bool) -> O
             .map(|node| {
                 let mut new_args = einsum.args.clone();
                 new_args[operand_idx].0 = node.clone();
-                Einsum::try_new(new_args, einsum.out_axes.clone(), None)
-                    .unwrap()
-                    .rc()
+                Einsum::nrc(new_args, einsum.out_axes.clone(), None)
             })
             .collect();
         Some(Add::try_new(summands, None).unwrap())
@@ -978,7 +951,7 @@ pub fn einsum_elim_zero(einsum: &Einsum) -> Option<ScalarConstant> {
 pub fn einsum_merge_scalars(einsum: &Einsum) -> Option<Einsum> {
     let mut num_scalars_found = 0;
     let mut scalar_mul: f64 = 1.0;
-    let mut new_args: Vec<(CircuitRc, Vec<u8>)> = einsum
+    let mut new_args: Vec<(CircuitRc, EinsumAxes)> = einsum
         .args
         .iter()
         .filter(|(node, _ints)| match &***node {
@@ -999,13 +972,13 @@ pub fn einsum_merge_scalars(einsum: &Einsum) -> Option<Einsum> {
         return None;
     }
     if scalar_mul != 1.0 {
-        new_args.push((ScalarConstant::new(scalar_mul, vec![], None).rc(), vec![]))
+        new_args.push((ScalarConstant::new(scalar_mul, sv![], None).rc(), sv![]))
     }
     Some(Einsum::try_new(new_args, einsum.out_axes.clone(), None).unwrap())
 }
 
 #[pyfunction]
-pub fn index_split_axes(node: &Index, top_axes: HashSet<usize>) -> Option<Index> {
+pub fn index_split_axes(node: &Index, top_axes: std::collections::HashSet<usize>) -> Option<Index> {
     let mut bottom: Vec<TensorAxisIndex> = vec![];
     let mut top: Vec<TensorAxisIndex> = vec![];
     if top_axes.iter().any(|i| *i >= node.node.info().rank()) {
@@ -1077,7 +1050,7 @@ pub fn generalfunction_evaluate_simple(node: &GeneralFunction) -> Option<Circuit
                     .unwrap()
                     .extract(py)
                     .unwrap(),
-                vec![],
+                sv![],
                 node.name_cloned(),
             )
             .rc()
@@ -1126,16 +1099,10 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                             }
                         })
                         .collect();
-                    Index::try_new(operand.clone(), TensorIndex(index_here), None)
-                        .unwrap()
-                        .rc()
+                    Index::nrc(operand.clone(), TensorIndex(index_here), None)
                 })
                 .collect();
-            Some(
-                Add::try_new(new_operands, inner.name_cloned())
-                    .unwrap()
-                    .rc(),
-            )
+            Some(Add::nrc(new_operands, inner.name_cloned()))
         }
         Circuit::Concat(inner) => {
             let index_non_axis = TensorIndex(
@@ -1152,7 +1119,9 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     })
                     .collect(),
             );
-            let shape_non_axis = filter_out_idx(&inner.info().shape, &HashSet::from([inner.axis]));
+            let shape_non_axis = filter_out_idx(&inner.info().shape, &HashSet::from([inner.axis]))
+                .into_iter()
+                .collect();
             if index_non_axis.is_identity(&shape_non_axis) {
                 return None;
             }
@@ -1163,27 +1132,21 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     .filter(|idx| matches!(idx, TensorAxisIndex::Single(_)))
                     .count();
 
-            let new_concat = Concat::try_new(
+            let new_concat = Concat::nrc(
                 inner
                     .nodes
                     .iter()
-                    .map(|operand| {
-                        Index::try_new(operand.clone(), index_non_axis.clone(), None)
-                            .unwrap()
-                            .rc()
-                    })
+                    .map(|operand| Index::nrc(operand.clone(), index_non_axis.clone(), None))
                     .collect(),
                 new_axis,
                 inner.name_cloned(),
-            )
-            .unwrap()
-            .rc();
+            );
             let final_index = TensorIndex::new_single(
                 node.index.0[inner.axis].clone(),
                 new_axis,
                 new_concat.info().rank(),
             );
-            Some(Index::try_new(new_concat, final_index, None).unwrap().rc())
+            Some(Index::nrc(new_concat, final_index, None))
         }
         Circuit::GeneralFunction(inner) => {
             if !inner.spec.is_batchable()
@@ -1203,18 +1166,14 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                                     .chain(vec![TensorAxisIndex::IDENT; ident_rank])
                                     .collect(),
                             );
-                            Index::try_new(child.clone(), index_passed, None)
-                                .unwrap()
-                                .rc()
+                            Index::nrc(child.clone(), index_passed, None)
                         } else {
                             child.clone()
                         }
                     })
                     .collect();
                 let new_gf =
-                    GeneralFunction::try_new(new_operands, inner.spec.clone(), inner.name_cloned())
-                        .unwrap()
-                        .rc();
+                    GeneralFunction::nrc(new_operands, inner.spec.clone(), inner.name_cloned());
                 let passed_rank_now = rank_to_pass
                     - (0..rank_to_pass)
                         .filter(|i| matches!(node.index.0[*i], TensorAxisIndex::Single(_)))
@@ -1226,7 +1185,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                         .chain(node.index.0[rank_to_pass..].iter().cloned())
                         .collect(),
                 );
-                Some(Index::try_new(new_gf, index_top, None).unwrap().rc())
+                Some(Index::nrc(new_gf, index_top, None))
             }
         }
         Circuit::Einsum(inner) => {
@@ -1242,7 +1201,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     }
                 }
             }
-            let ints_filter_index = |ints: &Vec<EinInt>| {
+            let ints_filter_index = |ints: &EinsumAxes| -> EinsumAxes {
                 ints.iter()
                     .filter_map(|i| {
                         match int_indices
@@ -1258,7 +1217,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     .collect()
             };
             let mut any_operand_index_nontrivial = false;
-            let new_operands: Vec<(CircuitRc, Vec<EinInt>)> = inner
+            let new_operands: Vec<(CircuitRc, EinsumAxes)> = inner
                 .args
                 .iter()
                 .map(|(node, ints)| {
@@ -1277,18 +1236,15 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                         any_operand_index_nontrivial = true;
                     }
                     (
-                        Index::try_new(node.clone(), index_here, None).unwrap().rc(),
-                        ints_filter_index(ints),
+                        Index::nrc(node.clone(), index_here, None),
+                        ints_filter_index(ints), // todo make function work with sv
                     )
                 })
                 .collect();
             if !any_operand_index_nontrivial {
                 return None;
             }
-            let new_einsum =
-                Einsum::try_new(new_operands, ints_filter_index(&inner.out_axes), None)
-                    .unwrap()
-                    .rc();
+            let new_einsum = Einsum::nrc(new_operands, ints_filter_index(&inner.out_axes), None);
             let out_index = TensorIndex(
                 zip(&inner.out_axes, &node.index.0)
                     .filter_map(|(i, idx)| match int_indices.get(i).unwrap() {
@@ -1300,7 +1256,7 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     })
                     .collect(),
             );
-            Some(Index::try_new(new_einsum, out_index, None).unwrap().rc())
+            Some(Index::nrc(new_einsum, out_index, None))
         }
         Circuit::Rearrange(inner) => {
             // doing this in python instead of porting to rust bc it has a lot of torch ops so likely wouldn't be faster in rust
@@ -1323,19 +1279,15 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
                     .ok()
             });
             python_result.map(|(index, spec)| {
-                let new_index = Index::try_new(inner.node.clone(), index, node.name_cloned())
-                    .unwrap()
-                    .rc();
-                Rearrange::try_new(new_index, spec, inner.name_cloned())
-                    .unwrap()
-                    .rc()
+                let new_index = Index::nrc(inner.node.clone(), index, node.name_cloned());
+                Rearrange::nrc(new_index, spec, inner.name_cloned())
             })
         }
         Circuit::Scatter(inner) => {
             // for now it just pushes indexes of Single(0) through axes size 1
             let mut new_outer = vec![];
             let mut new_scatter = vec![];
-            let mut new_scatter_shape = vec![];
+            let mut new_scatter_shape: Shape = sv![];
             let mut did_anything = false;
             let passed_index = zip(
                 &node.index.0,
@@ -1357,25 +1309,17 @@ pub fn push_down_index(node: &Index) -> Option<CircuitRc> {
             if !did_anything {
                 return None;
             }
-            let inner_node = Index::try_new(inner.node.clone(), TensorIndex(passed_index), None)
-                .unwrap()
-                .rc();
-            let result = Some(
-                Index::try_new(
-                    Scatter::try_new(
-                        inner_node,
-                        TensorIndex(new_scatter.iter().cloned().map(USlice::into).collect()),
-                        new_scatter_shape,
-                        None,
-                    )
-                    .unwrap()
-                    .rc(),
-                    TensorIndex(new_outer),
+            let inner_node = Index::nrc(inner.node.clone(), TensorIndex(passed_index), None);
+            let result = Some(Index::nrc(
+                Scatter::nrc(
+                    inner_node,
+                    TensorIndex(new_scatter.iter().cloned().map(USlice::into).collect()),
+                    new_scatter_shape,
                     None,
-                )
-                .unwrap()
-                .rc(),
-            );
+                ),
+                TensorIndex(new_outer),
+                None,
+            ));
             result
         }
         _ => None,
@@ -1406,31 +1350,25 @@ pub fn concat_repeat_to_rearrange(concat: &Concat) -> Option<Concat> {
                 did_anything = true;
                 let mut int_sizes = prev_node.info().shape.clone();
                 int_sizes.push(same_seen);
-                new_nodes.push(
-                    Rearrange::try_new(
-                        prev_node.clone(),
-                        RearrangeSpec {
-                            input_ints: (0..prev_node.info().rank())
-                                .map(|x| vec![x as u8])
-                                .collect(),
-                            output_ints: (0..prev_node.info().rank())
-                                .map(|x| {
-                                    if x == concat.axis {
-                                        // create group which is (count, axis_size) for total dim size of
-                                        // count * axis_size()
-                                        vec![prev_node.info().rank() as u8, x as u8]
-                                    } else {
-                                        vec![x as u8]
-                                    }
-                                })
-                                .collect(),
-                            int_sizes: shape_to_op_shape(&int_sizes),
-                        },
-                        None,
-                    )
-                    .unwrap()
-                    .rc(),
-                );
+                new_nodes.push(Rearrange::nrc(
+                    prev_node.clone(),
+                    RearrangeSpec {
+                        input_ints: (0..prev_node.info().rank()).map(|x| sv![x as u8]).collect(),
+                        output_ints: (0..prev_node.info().rank())
+                            .map(|x| {
+                                if x == concat.axis {
+                                    // create group which is (count, axis_size) for total dim size of
+                                    // count * axis_size()
+                                    sv![prev_node.info().rank() as u8, x as u8]
+                                } else {
+                                    sv![x as u8]
+                                }
+                            })
+                            .collect(),
+                        int_sizes: shape_to_op_shape(&int_sizes),
+                    },
+                    None,
+                ));
             } else {
                 new_nodes.push(prev_node.clone())
             }
@@ -1448,7 +1386,7 @@ pub fn concat_repeat_to_rearrange(concat: &Concat) -> Option<Concat> {
 
 #[test]
 fn basic_check_same_concat_shape() {
-    let a = Symbol::new_with_random_uuid(vec![2, 3, 4, 5, 6], None).rc();
+    let a = Symbol::new_with_random_uuid(sv![2, 3, 4, 5, 6], None).rc();
     let out = concat_repeat_to_rearrange(
         &Concat::try_new(vec![a.clone(), a.clone(), a], 3, None).unwrap(),
     )
