@@ -1,9 +1,6 @@
 use crate::pyo3_prelude::*;
 
-use super::{
-    deep_map_unwrap, Add, Circuit, CircuitNode, CircuitNodeUnion, CircuitRc, Einsum, Index,
-    Rearrange,
-};
+use super::{deep_map_unwrap, prelude::*, Add, Einsum, Index, Rearrange};
 
 /// takes circuitrc bc convenient
 pub fn numel_sort_key(node: &CircuitRc) -> Vec<u8> {
