@@ -50,6 +50,8 @@ pub struct OptimizationSettings {
     pub capture_and_print: bool,
     #[pyo3(get, set)]
     pub create_tests: bool,
+    #[pyo3(get, set)]
+    pub log_simplifications: bool,
 }
 
 #[cfg(not(feature = "real-pyo3"))]
@@ -73,6 +75,7 @@ impl Default for OptimizationSettings {
             numerical_scale_max: 1e8,
             capture_and_print: false,
             create_tests: false,
+            log_simplifications: false,
         }
     }
 }
@@ -91,7 +94,8 @@ impl OptimizationSettings {
         numerical_scale_min = "OptimizationSettings::default().numerical_scale_min",
         numerical_scale_max = "OptimizationSettings::default().numerical_scale_max",
         capture_and_print = "OptimizationSettings::default().capture_and_print",
-        create_tests = "OptimizationSettings::default().create_tests"
+        create_tests = "OptimizationSettings::default().create_tests",
+        log_simplifications = "OptimizationSettings::default().log_simplifications"
     )]
     fn new(
         verbose: usize,
@@ -105,6 +109,7 @@ impl OptimizationSettings {
         numerical_scale_max: f64,
         capture_and_print: bool,
         create_tests: bool,
+        log_simplifications: bool,
     ) -> Self {
         Self {
             verbose,
@@ -118,6 +123,7 @@ impl OptimizationSettings {
             numerical_scale_max,
             capture_and_print,
             create_tests,
+            log_simplifications,
         }
     }
 }
@@ -128,6 +134,7 @@ pub struct OptimizationCache {
     pub distributed: HashMap<HashBytes, Option<CircuitRc>>,
     pub flops: HashMap<HashBytes, BigUint>,
     pub sum_of_node_sizes: HashMap<HashBytes, BigUint>,
+    pub simplification_log: Vec<&'static str>,
 }
 
 #[derive(Debug, Clone, Default)]
