@@ -1,4 +1,4 @@
-use std::collections::HashMap;
+use crate::hashmaps::FxHashMap as HashMap;
 
 use crate::pyo3_prelude::*;
 use num_bigint::BigUint;
