@@ -1168,11 +1168,7 @@ impl Scatter {
         name: Option<String>,
     ) -> (Result<Self, CircuitConstructionError>) {
         let index_shape = index.apply_to_shape(&shape);
-        if index
-            .0
-            .iter()
-            .any(|x| !matches!(x, TensorAxisIndex::Slice(_)))
-        {
+        if index.all_uslices().is_none() {
             return Err(CircuitConstructionError::ScatterUnimplemented { index });
         }
         if index_shape[..] != node.info().shape[..] {
