@@ -1,4 +1,4 @@
-use std::collections::HashMap;
+use crate::hashmaps::FxHashMap as HashMap;
 use std::io::{Read, Write};
 
 use crate::circuit::circuit_optimizer::OptimizationContext;
@@ -64,8 +64,8 @@ pub fn assert_is_close(a: CircuitRc, b: CircuitRc) {
         println!("{:?}", close_result);
         println!("LHS: {}", rust_expression_notation_circuit(a));
         println!("RHS: {}", rust_expression_notation_circuit(b));
-        python_print(&a_ten.tensor());
-        python_print(&b_ten.tensor());
+        python_print(a_ten.tensor());
+        python_print(b_ten.tensor());
         panic!("circuits did not evaluate to the same tensors");
     }
 }
@@ -78,7 +78,7 @@ pub fn opt_eval_each_subcircuit_until_fail(circuit: CircuitRc, settings: Optimiz
         if circ.info().numel() < max_numel {
             let reference = evaluate_fn(&circ).unwrap();
             let optimized = optimize_and_evaluate(circ.clone(), settings);
-            if !optimized.is_err() {
+            if optimized.is_ok() {
                 let optimized = optimized.unwrap();
                 let close_result = is_close(reference, optimized);
                 if close_result.is_err() {
@@ -118,7 +118,7 @@ pub fn randn_ablate_great_grandchildren(circ: CircuitRc) -> CircuitRc {
             great_grandchild.info().hash_usize(),
         ))
         .rc();
-        replacements.insert(great_grandchild.info().hash.clone(), ablated);
+        replacements.insert(great_grandchild.info().hash, ablated);
     }
     replace_nodes(circ, &replacements)
 }
@@ -152,8 +152,8 @@ pub fn create_circuit_test(
         a.info().hash_usize(),
         b.info().hash_usize()
     );
-    let a_str = rust_expression_notation_circuit(a.clone());
-    let b_str = rust_expression_notation_circuit(b.clone());
+    let a_str = rust_expression_notation_circuit(a);
+    let b_str = rust_expression_notation_circuit(b);
     let test = format!(
         "#[test]\
         \nfn {}() {{\
@@ -162,9 +162,9 @@ pub fn create_circuit_test(
         \n    let b = {};\
         \n    assert_is_close(a, b);\
         \n}}\n",
-        name.clone(),
-        a_str.replace("\n", "\n    "),
-        b_str.replace("\n", "\n    ")
+        name,
+        a_str.replace('\n', "\n    "),
+        b_str.replace('\n', "\n    ")
     );
 
     let mut file = std::fs::OpenOptions::new()
