@@ -29,21 +29,31 @@ use super::{
 #[pyfunction]
 #[pyo3(name = "compiler_simp_step")]
 pub fn compiler_simp_step_py(circ: CircuitRc) -> Option<CircuitRc> {
-    compiler_simp_step(&circ)
+    compiler_simp_step(&circ, &mut Default::default())
 }
 
-pub fn compiler_simp_step(circuit: &Circuit) -> Option<CircuitRc> {
+pub fn compiler_simp_step(
+    circuit: &Circuit,
+    context: &mut OptimizationContext,
+) -> Option<CircuitRc> {
     macro_rules! f_wrap {
         ($f:expr) => {
-            &|x| $f(x).map(|v| v.rc())
+            (stringify!($f), &|x| $f(x).map(|v| v.rc()))
+        };
+    }
+
+    macro_rules! l_wrap {
+        ($f:expr) => {
+            (stringify!($f), &|x| $f(x))
         };
     }
 
     fn simp<'a, T: CircuitNode + Into<Circuit> + Clone>(
         x: &'a T,
-        fns: &[&dyn Fn(&'a T) -> Option<CircuitRc>],
+        fns: &[(&'static str, &dyn Fn(&'a T) -> Option<CircuitRc>)],
+        context: &mut OptimizationContext,
     ) -> Option<CircuitRc> {
-        for f in fns {
+        for (name, f) in fns {
             if let Some(result) = f(x) {
                 if **result == x.clone().c() {
                     println!("{}", stringify!(f));
@@ -51,6 +61,10 @@ pub fn compiler_simp_step(circuit: &Circuit) -> Option<CircuitRc> {
                     result.compiler_print();
                     panic!()
                 }
+                if context.settings.log_simplifications {
+                    println!("{}", name);
+                    context.cache.simplification_log.push(name);
+                }
                 return Some(result);
             }
         }
@@ -60,78 +74,76 @@ pub fn compiler_simp_step(circuit: &Circuit) -> Option<CircuitRc> {
 
     match &*circuit {
         Circuit::Add(node) => {
-            let fns: &[&dyn Fn(_) -> _] = &[
-                &remove_add_few_input,
+            let fns: &[(&'static str, &dyn Fn(_) -> _)] = &[
+                l_wrap!(&remove_add_few_input),
                 f_wrap!(add_flatten_once),
                 f_wrap!(add_elim_zeros),
                 f_wrap!(add_collapse_scalar_inputs),
-                &f_wrap!(add_deduplicate),
-                &|x| add_pull_removable_axes(x, true),
-                &f_wrap!(add_pull_scatter),
-                &f_wrap!(add_pull_diags),
+                f_wrap!(add_deduplicate),
+                l_wrap!(|x| add_pull_removable_axes(x, true)),
+                f_wrap!(add_pull_scatter),
+                f_wrap!(add_pull_diags),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::Einsum(node) => {
-            let fns: &[&dyn Fn(_) -> _] = &[
+            let fns: &[(&'static str, &dyn Fn(_) -> _)] = &[
                 f_wrap!(&einsum_elim_zero),
-                &einsum_elim_identity,
+                l_wrap!(einsum_elim_identity),
                 f_wrap!(&einsum_flatten_once),
                 f_wrap!(&einsum_of_permute_merge),
                 f_wrap!(&einsum_merge_scalars),
-                &einsum_pull_removable_axes,
-                &einsum_pull_scatter,
+                l_wrap!(einsum_pull_removable_axes),
+                l_wrap!(einsum_pull_scatter),
                 f_wrap!(&einsum_push_down_trace),
-                // &einsum_pull_concat,
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::Index(node) => {
-            let fns: &[&dyn Fn(_) -> _] = &[
-                &index_elim_identity,
+            let fns: &[(&'static str, &dyn Fn(_) -> _)] = &[
+                l_wrap!(index_elim_identity),
                 f_wrap!(&index_fuse),
-                &index_merge_scalar,
-                &index_einsum_to_scatter,
-                &index_concat_drop_unreached,
+                l_wrap!(index_merge_scalar),
+                l_wrap!(index_einsum_to_scatter),
+                l_wrap!(index_concat_drop_unreached),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::Rearrange(node) => {
-            let fns: &[&dyn Fn(_) -> _] = &[
-                &rearrange_elim_identity,
+            let fns: &[(&'static str, &dyn Fn(_) -> _)] = &[
+                l_wrap!(rearrange_elim_identity),
                 f_wrap!(&rearrange_fuse),
-                &rearrange_merge_scalar,
+                l_wrap!(rearrange_merge_scalar),
                 f_wrap!(&permute_of_einsum_merge),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::Concat(node) => {
-            let fns: &[&dyn Fn(&Concat) -> _] = &[
-                &concat_elim_identity,
-                &concat_pull_removable_axes,
-                &concat_merge_uniform,
+            let fns: &[(&'static str, &dyn Fn(&Concat) -> _)] = &[
+                l_wrap!(concat_elim_identity),
+                l_wrap!(concat_pull_removable_axes),
+                l_wrap!(concat_merge_uniform),
                 f_wrap!(&concat_drop_size_zero),
                 f_wrap!(&concat_fuse),
                 f_wrap!(&concat_repeat_to_rearrange),
                 f_wrap!(&concat_to_scatter),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::GeneralFunction(node) => {
-            let fns: &[&dyn Fn(&GeneralFunction) -> _] = &[
-                &generalfunction_pull_removable_axes,
-                &generalfunction_evaluate_simple,
-                // f_wrap!(&generalfunction_pull_concat),
+            let fns: &[(&'static str, &dyn Fn(&GeneralFunction) -> _)] = &[
+                l_wrap!(generalfunction_pull_removable_axes),
+                l_wrap!(generalfunction_evaluate_simple),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         Circuit::Scatter(node) => {
-            let fns: &[&dyn Fn(_) -> _] = &[
-                &scatter_elim_identity,
+            let fns: &[(&'static str, &dyn Fn(_) -> _)] = &[
+                l_wrap!(scatter_elim_identity),
                 f_wrap!(&scatter_fuse),
                 f_wrap!(&scatter_pull_removable_axes),
             ];
-            simp(node, fns)
+            simp(node, fns, context)
         }
         _ => None,
     }
@@ -154,46 +166,48 @@ pub fn compiler_simp(circ: &Circuit, opt_context: &mut OptimizationContext) -> C
     /// check if any new children have not been simplified yet, and simplify them if so
     fn simplify_changed_descendants(
         circ: &Circuit,
-        simplified: &mut HashMap<HashBytes, CircuitRc>,
+        context: &mut OptimizationContext,
     ) -> Option<CircuitRc> {
         // if let Some(changed) = compiler_simp_step(circ){
         //     return simplify_changed_descendants(circ, simplified)
         // }
         circ.map_children_op(&mut |x: &Circuit| {
-            if simplified.contains_key(&x.info().hash) {
+            if context.cache.simplified.contains_key(&x.info().hash) {
                 None
             } else {
-                Some(fully_simplify(x.clone().rc(), simplified))
+                Some(fully_simplify(x.clone().rc(), context))
             }
         })
         .map(|c| c.rc())
     }
     /// fully simplify a circuit and all its descendants recursively until we hit a fixed point
-    fn fully_simplify(
-        circ: CircuitRc,
-        simplified: &mut HashMap<HashBytes, CircuitRc>,
-    ) -> CircuitRc {
-        if let Some(result) = simplified.get(&circ.info().hash) {
+    fn fully_simplify(circ: CircuitRc, context: &mut OptimizationContext) -> CircuitRc {
+        if let Some(result) = context.cache.simplified.get(&circ.info().hash) {
             return result.clone();
         }
         let mut result: CircuitRc = circ
-            .map_children_unwrap(&mut |x: &Circuit| fully_simplify(x.clone().rc(), simplified))
+            .map_children_unwrap(&mut |x: &Circuit| fully_simplify(x.clone().rc(), context))
             .rc();
         for iter_count in 0.. {
-            match compiler_simp_step(&result) {
-                Some(r) => result = simplify_changed_descendants(&r, simplified).unwrap_or(r),
+            match compiler_simp_step(&result, context) {
+                Some(r) => result = simplify_changed_descendants(&r, context).unwrap_or(r),
                 None => break,
             }
             if iter_count > 50 {
                 result.compiler_print();
-                compiler_simp_step(&result).unwrap().compiler_print();
+                compiler_simp_step(&result, context)
+                    .unwrap()
+                    .compiler_print();
                 panic!();
             }
         }
-        simplified.insert(circ.info().hash, result.clone());
+        context
+            .cache
+            .simplified
+            .insert(circ.info().hash, result.clone());
         result
     }
-    fully_simplify(circ.clone().rc(), &mut opt_context.cache.simplified)
+    fully_simplify(circ.clone().rc(), opt_context)
 }
 
 #[pyfunction]
@@ -327,7 +341,10 @@ pub fn deep_pull_concat_messy(circuit: CircuitRc, min_size: Option<usize>) -> Ci
 pub fn deep_pull_concat(circuit: CircuitRc, min_size: Option<usize>) -> CircuitRc {
     let mut cache = Default::default();
     let pulled = deep_pull_concat_messy(circuit, min_size);
+    pulled.compiler_print();
     apply_fn_until_same(&pulled, |x: &CircuitRc| {
-        deep_push_down_index(compiler_simp(x, &mut cache), min_size)
+        let result = deep_push_down_index(compiler_simp(x, &mut cache), min_size);
+        result.compiler_print();
+        result
     })
 }
