@@ -231,7 +231,7 @@ pub trait CircuitNode: CircuitNodePrivate {
         let named_axes = if self.children().any(|x| !x.info().named_axes.is_empty()) {
             self.compute_named_axes()
         } else {
-            vec![]
+            vec![None; shape.len()]
         };
         hasher.update(self.name().unwrap_or("").as_bytes());
         hasher.update(&self.node_type_uuid());
