@@ -16,6 +16,7 @@ mod pyo3_prelude {
     pub use fake_pyo3::noop as args;
     pub use fake_pyo3::noop as pyo3;
     pub use fake_pyo3::noop as staticmethod;
+    /// This class ignores pyo3 attributes
     pub use fake_pyo3::FakePyClassDeriv as PyClassDeriv;
     pub use pyo3::prelude::{
         wrap_pyfunction, FromPyObject, GILGuard, IntoPy, IntoPyPointer, Py, PyAny, PyCell,
@@ -34,9 +35,11 @@ use crate::pyo3_prelude::*;
 pub mod all_imports;
 mod caching;
 pub mod circuit;
+pub mod hashmaps;
 pub mod opt_einsum;
 pub mod py_types;
 pub mod rearrange_spec;
+pub mod smallvec;
 pub mod tensor_util;
 mod union_find;
 pub mod util;
@@ -49,15 +52,14 @@ pub mod util;
 fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     use circuit::algebraic_rewrite::{
         add_collapse_scalar_inputs, add_deduplicate, add_elim_zeros, add_flatten_once,
-        add_make_broadcasts_explicit, add_outer_product_broadcasts_on_top, add_pull_removable_axes,
-        concat_elim_identity, concat_merge_uniform, concat_pull_removable_axes,
-        concat_repeat_to_rearrange, deep_optimize_einsums, distribute, distribute_all,
-        einsum_elim_identity, einsum_elim_zero, einsum_flatten_once, einsum_merge_scalars,
-        einsum_nest_optimize, einsum_nest_path, einsum_of_permute_merge,
-        einsum_pull_removable_axes, extract_add, generalfunction_pull_removable_axes,
-        index_elim_identity, index_fuse, index_merge_scalar, index_split_axes,
-        permute_of_einsum_merge, push_down_index, rearrange_elim_identity, rearrange_fuse,
-        rearrange_merge_scalar, remove_add_few_input,
+        add_make_broadcasts_explicit, add_pull_removable_axes, concat_elim_identity,
+        concat_merge_uniform, concat_pull_removable_axes, concat_repeat_to_rearrange,
+        deep_optimize_einsums, distribute, distribute_all, einsum_elim_identity, einsum_elim_zero,
+        einsum_flatten_once, einsum_merge_scalars, einsum_nest_optimize, einsum_nest_path,
+        einsum_of_permute_merge, einsum_pull_removable_axes, extract_add,
+        generalfunction_pull_removable_axes, index_elim_identity, index_fuse, index_merge_scalar,
+        index_split_axes, permute_of_einsum_merge, push_down_index, rearrange_elim_identity,
+        rearrange_fuse, rearrange_merge_scalar, remove_add_few_input,
     };
     use circuit::batching::{batch_inputs_axis_len, batch_largest};
     use circuit::canonicalize::{canonicalize_node_py, deep_canonicalize};
@@ -217,6 +219,10 @@ fn rust_circuit(py: Python<'_>, m: &PyModule) -> PyResult<()> {
     m.add_function(wrap_pyfunction!(einsum_push_down_trace, m)?)?;
     m.add_function(wrap_pyfunction!(concat_repeat_to_rearrange, m)?)?;
     m.add_function(wrap_pyfunction!(extract_add, m)?)?;
+    m.add_function(wrap_pyfunction!(
+        circuit::scatter_rewrite::concat_to_scatter,
+        m
+    )?)?;
     m.add_function(wrap_pyfunction!(
         circuit::debugging::opt_eval_each_subcircuit_until_fail,
         m
