@@ -1,3 +1,5 @@
+use crate::circuit::EinsumAxes;
+use crate::hashmaps::{AHashSet as HashSet, FxHashMap as HashMap};
 /// This file optimizes tensor contraction order, like Python's opt_einsum
 /// It specifies contraction order using rotating id's, like opt_einsum or numpy,
 /// which is kindof awkward but compatible
@@ -11,7 +13,7 @@
 use crate::pyo3_prelude::*;
 use crate::{
     union_find::UnionFind,
-    util::{dict_to_list, EinInt, ALPHABET, ALPHABET_INV},
+    util::{dict_to_list, ALPHABET, ALPHABET_INV},
 };
 use cached::proc_macro::cached;
 use num_bigint::BigUint;
@@ -22,7 +24,6 @@ use pyo3::{
 
 use std::{
     cmp::{max, min},
-    collections::{HashMap, HashSet},
     rc::Rc,
 };
 
@@ -317,7 +318,7 @@ impl EinsumSpec {
     }
 
     #[staticmethod]
-    pub fn string_to_ints(string: String) -> (Vec<Vec<EinInt>>, Vec<EinInt>) {
+    pub fn string_to_ints(string: String) -> (Vec<EinsumAxes>, EinsumAxes) {
         if let [inputs, output] = string.split("->").collect::<Vec<&str>>()[..] {
             let output_ints = output
                 .chars()
